@@ -1053,8 +1053,8 @@ def box(
         b = a
     i = Interval(a,b)
     return Pbox(
-        left = a,
-        right = b,
+        left = np.repeat(a,steps),
+        right = np.repeat(b,steps),
         mean_left = i.left,
         mean_right= i.right,
         var_left = 0,
